@@ -41,42 +41,42 @@
 #' }
 #' }
 #'
-#' @import shiny
-#' @importFrom htmltools validateCssUnit
+#' @importFrom shiny restoreInput
+#' @importFrom htmltools tags validateCssUnit
 #'
 #' @export
 
 searchInput <- function(inputId, label = NULL, value = "", placeholder = NULL,
                         btnSearch = NULL, btnReset = NULL, width = NULL) {
-
+  value <- shiny::restoreInput(id = inputId, default = value)
   if (!is.null(btnSearch)) {
-    btnSearch <- tags$button(
+    btnSearch <- htmltools::tags$button(
       class="btn btn-default action-button",
       id = paste0(inputId, "_search"),
       type="button", btnSearch
     )
   }
   if (!is.null(btnReset)) {
-    btnReset <- tags$button(
+    btnReset <- htmltools::tags$button(
       class="btn btn-default action-button",
       id = paste0(inputId, "_reset"),
       type="button", btnReset
     )
   }
 
-  searchTag <- div(
+  searchTag <- htmltools::tags$div(
     class="form-group shiny-input-container",
     style = if (!is.null(width))
       paste0("width: ", validateCssUnit(width), ";"),
-    if (!is.null(label)) tags$label(label, `for` = inputId),
-    div(
+    if (!is.null(label)) htmltools::tags$label(label, `for` = inputId),
+    htmltools::tags$div(
       id = inputId,
       class = "input-group search-text",
-      tags$input(id = paste0("se", inputId),
+      htmltools::tags$input(id = paste0("se", inputId),
                  style = "border-radius: 0.5em 0 0 0.5em !important;",
                  type = "text", class = "form-control", value = value,
                  placeholder = placeholder),
-      tags$span(class="input-group-btn", btnReset, btnSearch)
+      htmltools::tags$span(class="input-group-btn", btnReset, btnSearch)
     )
   )
   # Dep
