@@ -14,5 +14,5 @@ shinyWidgetsGallery <- function() {
     message("Package 'shinydashboard' is required to run this function")
   if (!requireNamespace(package = "formatR"))
     message("Package 'formatR' is required to run this function")
-  shiny::runApp(system.file('examples/shinyWidgets', package='shinyWidgets', mustWork=TRUE))
+  shiny::shinyAppDir(system.file('examples/shinyWidgets', package='shinyWidgets', mustWork=TRUE))
 }
